# Installation

NeoPika supports Python `3.6+`. It may also work on PyPy, Cython, and Jython, but is not being tested for these versions.

To install NeoPika run the following command:

```bash
pip install neopika
```

## Dependencies

NeoPika has no external dependencies. It only uses Python standard library modules. 